@@ -19,6 +19,7 @@
 */
 
 #include "mainwidget.h"
+#include "helper_p.h"
 #include "contactswitcher.h"
 #include "globalcontactmodel.h"
 #include "modelcolumnmanager.h"
@@ -29,6 +30,7 @@
 #include "categoryselectwidget.h"
 #include "categoryfilterproxymodel.h"
 #include "kaddressbook_options.h"
+#include "manageshowcollectionproperties.h"
 
 #include "KaddressbookGrantlee/GrantleeContactFormatter"
 #include "KaddressbookGrantlee/GrantleeContactGroupFormatter"
@@ -36,8 +38,8 @@
 
 #include "Libkdepim/UiStateSaver"
 
-#include <PimCommon/CollectionAclPage>
-#include <PimCommon/ImapAclAttribute>
+#include <PimCommonAkonadi/ImapAclAttribute>
+#include <PimCommonAkonadi/MailUtil>
 
 #include <AkonadiWidgets/ETMViewStateSaver>
 #include <AkonadiCore/CollectionFilterProxyModel>
@@ -51,7 +53,7 @@
 #include <AkonadiSearch/Debug/akonadisearchdebugdialog.h>
 #include <KContacts/Addressee>
 #include <QPointer>
-#include "PimCommon/ManageServerSideSubscriptionJob"
+#include "PimCommonAkonadi/ManageServerSideSubscriptionJob"
 #include "PimCommon/PimUtil"
 #include <KAddressBookImportExport/KAddressBookImportExportPluginManager>
 #include <KAddressBookImportExport/KAddressBookImportExportPlugin>
@@ -101,10 +103,9 @@ namespace
 {
 static bool isStructuralCollection(const Akonadi::Collection &collection)
 {
-    QStringList mimeTypes;
-    mimeTypes << KContacts::Addressee::mimeType() << KContacts::ContactGroup::mimeType();
+    const QStringList mimeTypes = {KContacts::Addressee::mimeType(), KContacts::ContactGroup::mimeType()};
     const QStringList collectionMimeTypes = collection.contentMimeTypes();
-    foreach (const QString &mimeType, mimeTypes) {
+    for (const QString &mimeType : mimeTypes) {
         if (collectionMimeTypes.contains(mimeType)) {
             return false;
         }
@@ -142,16 +143,17 @@ public:
 
 MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     : QWidget(parent),
-      mAllContactsModel(Q_NULLPTR),
+      mAllContactsModel(nullptr),
       mXmlGuiClient(guiClient),
-      mGrantleeThemeManager(Q_NULLPTR),
-      mQuickSearchAction(Q_NULLPTR),
-      mServerSideSubscription(Q_NULLPTR)
+      mGrantleeThemeManager(nullptr),
+      mQuickSearchAction(nullptr),
+      mServerSideSubscription(nullptr)
 {
 
     (void) new KaddressbookAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KAddressBook"), this);
 
+    mManageShowCollectionProperties = new ManageShowCollectionProperties(this, this);
     mImportExportPluginManager = KAddressBookImportExport::KAddressBookImportExportPluginManager::self();
 
     Akonadi::AttributeFactory::registerAttribute<PimCommon::ImapAclAttribute>();
@@ -291,7 +293,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
                     << Akonadi::StandardActionManager::MoveItemToMenu
                     << Akonadi::StandardActionManager::CopyItemToMenu;
 
-    Q_FOREACH (Akonadi::StandardActionManager::Type standardAction, standardActions) {
+    for (Akonadi::StandardActionManager::Type standardAction : qAsConst(standardActions)) {
         mActionManager->createAction(standardAction);
     }
     guiClient->actionCollection()->setDefaultShortcut(mActionManager->action(Akonadi::StandardActionManager::DeleteItems), QKeySequence(Qt::Key_Delete));
@@ -300,22 +302,12 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
                    << Akonadi::StandardContactActionManager::CreateContactGroup
                    << Akonadi::StandardContactActionManager::EditItem;
 
-    Q_FOREACH (Akonadi::StandardContactActionManager::Type contactAction, contactActions) {
+    for (Akonadi::StandardContactActionManager::Type contactAction : qAsConst(contactActions)) {
         mActionManager->createAction(contactAction);
     }
-    static bool pageRegistered = false;
 
-    if (!pageRegistered) {
-        Akonadi::CollectionPropertiesDialog::registerPage(new PimCommon::CollectionAclPageFactory);
-        pageRegistered = true;
-    }
-
-    const QStringList pages =
-        QStringList() << QStringLiteral("Akonadi::CollectionGeneralPropertiesPage")
-        << QStringLiteral("Akonadi::CachePolicyPage")
-        << QStringLiteral("PimCommon::CollectionAclPage");
-
-    mActionManager->setCollectionPropertiesPageNames(pages);
+    mActionManager->interceptAction(Akonadi::StandardActionManager::CollectionProperties);
+    connect(mActionManager->action(Akonadi::StandardActionManager::CollectionProperties), &QAction::triggered, mManageShowCollectionProperties, &ManageShowCollectionProperties::showCollectionProperties);
 
     connect(mItemView, SIGNAL(currentChanged(Akonadi::Item)),
             this, SLOT(itemSelected(Akonadi::Item)));
@@ -352,7 +344,7 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
     const QVector<KAddressBookImportExport::KAddressBookImportExportPlugin *> listPlugins = KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->pluginsList();
     QList<QAction *> importActions;
     QList<QAction *> exportActions;
-    Q_FOREACH (KAddressBookImportExport::KAddressBookImportExportPlugin *plugin, listPlugins) {
+    for (KAddressBookImportExport::KAddressBookImportExportPlugin *plugin : listPlugins) {
         if (plugin->isEnabled()) {
             KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface = static_cast<KAddressBookImportExport::KAddressBookImportExportPluginInterface *>(plugin->createInterface(collection, this));
             interface->setItemSelectionModel(mItemView->selectionModel());
@@ -367,14 +359,14 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
     if (!importActions.isEmpty()) {
         KActionMenu *importMenu = new KActionMenu(i18n("Import"), this);
         collection->addAction(QStringLiteral("import_menu"), importMenu);
-        Q_FOREACH (QAction *act, importActions) {
+        for (QAction *act : qAsConst(importActions)) {
             importMenu->addAction(act);
         }
     }
     if (!exportActions.isEmpty()) {
         KActionMenu *exportMenu = new KActionMenu(i18n("Export"), this);
         collection->addAction(QStringLiteral("export_menu"), exportMenu);
-        Q_FOREACH (QAction *act, exportActions) {
+        for (QAction *act : qAsConst(exportActions)) {
             exportMenu->addAction(act);
         }
     }
@@ -399,7 +391,7 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
     if (parser.isSet(QStringLiteral("import"))) {
         for (const QString &urlStr : parser.positionalArguments()) {
             const QUrl url(QUrl::fromUserInput(urlStr));
-            Q_FOREACH (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface, mImportExportPluginInterfaceList) {
+            for (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
                 if (interface->canImportFileType(url)) {
                     interface->importFile(url);
                     break;
@@ -997,7 +989,7 @@ Akonadi::EntityTreeModel *MainWidget::entityTreeModel() const
     }
 
     qCWarning(KADDRESSBOOK_LOG) << "Couldn't find EntityTreeModel";
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void MainWidget::slotCheckNewCalendar(const QModelIndex &parent, int begin, int end)
@@ -1076,10 +1068,10 @@ void MainWidget::slotServerSideSubscription()
 
 void MainWidget::slotCurrentCollectionChanged(const Akonadi::Collection &col)
 {
-    Q_FOREACH (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface, mImportExportPluginInterfaceList) {
+    for (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
         interface->setDefaultCollection(col);
     }
     bool isOnline;
-    mServerSideSubscription->setEnabled(PimCommon::Util::isImapFolder(col, isOnline));
+    mServerSideSubscription->setEnabled(PimCommon::MailUtil::isImapFolder(col, isOnline));
 }
 
