@@ -25,6 +25,7 @@
 #include "kaddressbookimportexportcontactfields.h"
 #include "printprogress.h"
 #include "printstyle.h"
+#include "helper_p.h"
 #include "printingwizard.h"
 #include "ui_compactstyle.h"
 
@@ -97,10 +98,10 @@ QString CompactStyle::contactsToHtml(const KContacts::Addressee::List &contacts)
     content += QLatin1String("  <table style=\"font-size:50%; border-width: 0px; \"width=\"100%\">\n");
 
     bool odd = false;
-    foreach (const KContacts::Addressee &contact, contacts) {
+    for (const KContacts::Addressee &contact : contacts) {
         // get the values
         QStringList values;
-        foreach (const KAddressBookImportExport::KAddressBookImportExportContactFields::Field &field, fields) {
+        for (const KAddressBookImportExport::KAddressBookImportExportContactFields::Field &field : qAsConst(fields)) {
             // we need only values with content
             const QString value = KAddressBookImportExport::KAddressBookImportExportContactFields::value(field, contact).trimmed();
             if (!value.isEmpty()) {
