@@ -3,7 +3,7 @@
   Copyright (c) 1996-2002 Mirko Boehm <mirko@kde.org>
                           Tobias Koenig <tokoe@kde.org>
 
-  Copyright (c) 2009-2016 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2017 Laurent Montel <montel@kde.org>
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
@@ -25,6 +25,7 @@
 
 #include "printingwizard.h"
 #include "settings.h"
+#include "helper_p.h"
 
 #include <KAddressBookImportExport/KAddressBookContactSelectionWidget>
 #include "contactsorter.h"
@@ -53,7 +54,7 @@ using namespace KABPrinting;
 
 PrintingWizard::PrintingWizard(QPrinter *printer, QItemSelectionModel *selectionModel,
                                QWidget *parent)
-    : KAssistantDialog(parent), mPrinter(printer), mStyle(Q_NULLPTR)
+    : KAssistantDialog(parent), mPrinter(printer), mStyle(nullptr)
 {
     setWindowTitle(i18n("Print Contacts"));
 
@@ -127,7 +128,7 @@ void PrintingWizard::loadGrantleeStyle()
         }
     }
 
-    Q_FOREACH (const QString &directory, themesDirectories) {
+    for (const QString &directory : qAsConst(themesDirectories)) {
         QDirIterator dirIt(directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot);
         QStringList alreadyLoadedThemeName;
         while (dirIt.hasNext()) {
