@@ -3,7 +3,7 @@
   Copyright (c) 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
                      Tobias Koenig <tokoe@kde.org>
 
-  Copyright (c) 2009-2016 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ class StylePage : public QWidget
     Q_OBJECT
 
 public:
-    explicit StylePage(QWidget *parent = Q_NULLPTR, const QString &name = QString());
+    explicit StylePage(QWidget *parent = nullptr, const QString &name = QString());
     ~StylePage();
 
     /**
